@@ -14,7 +14,7 @@ class UploadTests(unittest.TestCase):
     '''Test runner regarding upload functionality'''
 
     def setUp(self) -> None:
-        ge.reset()
+        ge.reset(False)
 
     def test_upload(self):
         with requests_mock.Mocker() as m:
